==> libphidget_2.1.7.20110222-1.tar.gz: phidget21/Java/com/phidgets/event/GPSPositionChangeEvent.java <==
/*
 * Copyright 2006 Phidgets Inc.  All rights reserved.
 */

package com.phidgets.event;

import com.phidgets.Phidget;

/**
 * This class represents the data for a GPSPositionChangeEvent.
 * 
 * @author Phidgets Inc.
 */   
public class GPSPositionChangeEvent
{
	Phidget source;
	double latitude;
	double longitude;
	double altitude;

	/**
	 * Class constructor. This is called internally by the phidget library when creating this event.
	 * 
	 * @param source the Phidget object from which this event originated
	 */
	public GPSPositionChangeEvent(Phidget source, double latitude,	double longitude, double altitude) {
		this.source = source;
		this.latitude = latitude;
		this.longitude = longitude;
		this.altitude = altitude;
	}

	/**
	 * Returns the source Phidget of this event. This is a reference to the Phidget object from which this
	 * event was called. This object can be cast into a specific type of Phidget object to call specific
	 * device calls on it.
	 * 
	 * @return the event caller
	 */
	public Phidget getSource() {
		return source;
	}

	/**
	 * Returns the index of the temperature sensor. An index of 0 indicated the Cold Juction Temperature sensing IC.
	 * An index of 1 indicated the thermocouple.
	 * 
	 * @return the index of the sensor
	 */
	public double getLatitude() {
		return latitude;
	}

	/**
	 * Returns the temperature of the sensor is degrees celcius.
	 * 
	 * @return the temperature of the sensor
	 */
	public double getLongitude() {
		return longitude;
	}

	/**
	 * Returns the temperature of the sensor is degrees celcius.
	 * 
	 * @return the temperature of the sensor
	 */
	public double getAltitude() {
		return altitude;
	}
	
	/**
	 * Returns a string containing information about the event.
	 * 
	 * @return an informative event string
	 */
	public String toString() {
		return("Position changed - Latitude: "+ latitude + " degrees" +
			", Longitude: " + longitude + " degrees" + ", Altitude: "+ altitude + "m");
	}
}

==> libphidget_2.1.8.20130722-1.tar.gz: phidget21/Java/com/phidgets/event/GPSPositionChangeEvent.java <==
/*
 * Copyright 2006 Phidgets Inc.  All rights reserved.
 */

package com.phidgets.event;

import com.phidgets.Phidget;

/**
 * This class represents the data for a GPSPositionChangeEvent.
 * 
 * @author Phidgets Inc.
 */   
public class GPSPositionChangeEvent
{
	Phidget source;
	double latitude;
	double longitude;
	double altitude;

	/**
	 * Class constructor. This is called internally by the phidget library when creating this event.
	 * 
	 * @param source the Phidget object from which this event originated
	 */
	public GPSPositionChangeEvent(Phidget source, double latitude,	double longitude, double altitude) {
		this.source = source;
		this.latitude = latitude;
		this.longitude = longitude;
		this.altitude = altitude;
	}

	/**
	 * Returns the source Phidget of this event. This is a reference to the Phidget object from which this
	 * event was called. This object can be cast into a specific type of Phidget object to call specific
	 * device calls on it.
	 * 
	 * @return the event caller
	 */
	public Phidget getSource() {
		return source;
	}

	/**
	 * Returns the latitude of the GPS, in signed degrees format.
	 * 
	 * @return the latitude
	 */
	public double getLatitude() {
		return latitude;
	}

	/**
	 * Returns the longitude of the GPS, in signed degrees format
	 * 
	 * @return the longitude
	 */
	public double getLongitude() {
		return longitude;
	}

	/**
	 * Returns the altitude of the GPS, in meters.
	 * 
	 * @return the altitude
	 */
	public double getAltitude() {
		return altitude;
	}
	
	/**
	 * Returns a string containing information about the event.
	 * 
	 * @return an informative event string
	 */
	public String toString() {
		return("Position is - Latitude: "+ latitude + " degrees" +
			", Longitude: " + longitude + " degrees" + ", Altitude: "+ altitude + "m");
	}
}
